==> fwbuilder_2.1.19.orig.tar.gz: fwbuilder-2.1.19/src/iosacl/OSConfigurator_ios.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2007 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: OSConfigurator_ios.h,v 1.1 2008/03/06 06:48:58 vkurland Exp $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


*/

#ifndef _OSNETWORKCONFIGURATOR_IOS_HH
#define _OSNETWORKCONFIGURATOR_IOS_HH

#include "config.h"

#include "fwcompiler/OSConfigurator.h"

#include <map>

namespace fwcompiler {

    class OSConfigurator_ios : public OSConfigurator {

        std::string _printNameif();
        std::string _printIPAddress();
        std::string _printLogging();

	public:

	virtual ~OSConfigurator_ios() {};
	OSConfigurator_ios(libfwbuilder::FWObjectDatabase *_db,const std::string &fwname) :
	    OSConfigurator(_db,fwname) {}

	virtual int  prolog();

	virtual std::string myPlatformName();
	virtual void processFirewallOptions();
	virtual void addVirtualAddressForNAT(const libfwbuilder::Address   *addr);
	virtual void addVirtualAddressForNAT(const libfwbuilder::Network   *nw);
    };
};

#endif

==> fwbuilder_3.0.7.orig.tar.gz: fwbuilder-3.0.7/src/iosacl/OSConfigurator_ios.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2007 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: OSConfigurator_ios.h 312 2008-07-05 17:40:12Z vadim $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


*/

#ifndef _OSNETWORKCONFIGURATOR_IOS_HH
#define _OSNETWORKCONFIGURATOR_IOS_HH

#include "config.h"

#include "fwcompiler/OSConfigurator.h"

#include <map>

namespace fwcompiler {

    class OSConfigurator_ios : public OSConfigurator {

        std::string _printNameif();
        std::string _printIPAddress();
        std::string _printLogging();

	public:

	virtual ~OSConfigurator_ios() {};
	OSConfigurator_ios(libfwbuilder::FWObjectDatabase *_db,
                           const std::string &fwname,
                           bool ipv6_policy) :
        OSConfigurator(_db, fwname, ipv6_policy) {}

	virtual int  prolog();

	virtual std::string myPlatformName();
	virtual void processFirewallOptions();
	virtual void addVirtualAddressForNAT(const libfwbuilder::Address   *addr);
	virtual void addVirtualAddressForNAT(const libfwbuilder::Network   *nw);
    };
};

#endif
